@@ -50,6 +50,10 @@ class Base(metaclass=MetaBase):
     def mutate(self):
         return self
 
+    @classmethod
+    def merge(cls, *args, **kwargs):
+        return None
+
     # Used when plotting
     def plot_map(self, backend):
         self._not_implemented()
@@ -77,6 +81,10 @@ class Base(metaclass=MetaBase):
     def to_bounding_box(self):
         self._not_implemented()
 
+    # For machine learning
+    def statistics(self):
+        self._not_implemented()
+
     #
     def _not_implemented(self):
         import inspect
