@@ -15,7 +15,7 @@ from multiurl import Downloader
 from climetlab.core.settings import SETTINGS
 from climetlab.core.statistics import record_statistics
 from climetlab.utils import tqdm
-from climetlab.utils.mirror import DEFAULT_MIRROR, mirror_writer
+from climetlab.utils.mirror import get_mirrors
 
 from .file import FileSource
 
@@ -48,8 +48,6 @@ class Url(FileSource):
         range_method="auto",
         http_headers=None,
         update_if_out_of_date=False,
-        mirror=DEFAULT_MIRROR,
-        build_mirror=None,
         fake_headers=None,  # When HEAD is not allowed but you know the size
     ):
 
@@ -63,10 +61,11 @@ class Url(FileSource):
 
         self.update_if_out_of_date = update_if_out_of_date
 
-        if mirror:
-            url = mirror(url)
-        if not build_mirror:
-            build_mirror = mirror_writer()
+        mirrors = get_mirrors()
+        mutator = mirrors.mutator(self)
+        if mutator:
+            self._mutator = mutator
+            return
 
         self.downloader = Downloader(
             url,
@@ -107,8 +106,17 @@ class Url(FileSource):
             extension=extension,
             force=force,
         )
-        if build_mirror:
-            build_mirror.build_mirror(self.path, self.url)
+
+        mirrors.copy(self)
+
+    def is_contained_by_mirror(self, mirror, **kwargs):
+        return mirror.contains_url(self, **kwargs)
+
+    def get_mirror_mutator(self, mirror, **kwargs):
+        return mirror.mutator_for_url(self, **kwargs)
+
+    def copy_to_mirror(self, mirror, **kwargs):
+        return mirror.copy_url(self, **kwargs)
 
     def out_of_date(self, url, path, cache_data):
         if SETTINGS.get("check-out-of-date-urls") is False:
